@@ -1,22 +1,30 @@
 'degreedistr' <-
-function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
+function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE, level="both", ...){
 
     # calculates cumulative degree distributions and fits exponential, power law
     # and truncated power law functions to it
     # return fits
- 	  web <- empty(web)
+    web <- empty(web)
     web <- (web>0)*1 #turns it into a qualitative network
     k <- sum(web) # number of links in network
     S <- sum(dim(web)) # number of species in network
     ddlower <- rowSums(web)
     ddhigher <- colSums(web)
 
+	if (level == "both"){
+		lower <- TRUE; higher <- TRUE
+	} else {
+		lower <- FALSE; higher <- FALSE
+		if (level =="lower") lower <- TRUE else higher <- TRUE
+	}
+
+
     Plo <- sapply(sort(unique(ddlower)), function(x) sum(ddlower>=x))
     Plower <- cbind.data.frame(k=sort(unique(ddlower)), P=Plo/max(Plo))
-    if (nrow(Plower) < 5) warning("Too few data points (< 5) for lower trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has one parameter more.")
+    if (lower & nrow(Plower) < 5) warning("Too few data points (< 5) for lower trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has one parameter more.")
     Phi <- sapply(sort(unique(ddhigher)), function(x) sum(ddhigher>=x))
     Phigher <- cbind.data.frame(k=sort(unique(ddhigher)), P=Phi/max(Phi))
-    if (max(Phigher) < 5) warning("Too few data levels of degrees (< 5) for higher trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has one parameter more.")
+    if (higher & max(Phigher) < 5) warning("Too few data levels of degrees (< 5) for higher trophic level! Fitting makes no sense! The truncated fit is the first to fail because it has one parameter more.")
 
     fitdd <- function(...){
     	 # Obviously, an intercept "b" has to be fitted, too.
@@ -47,8 +55,8 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
     }
 
 	# for 3 or fewer data points, fitting is silly. Thus, a first check is performed that returns try-errors if too few data points are found:
-	if (length(Plo) < 4){fitl <- list(try(sqrt("w"), silent=TRUE))} else {fitl <- fitdd(data=Plower, nls.control(maxiter=1000))}
-	if (length(Phi) < 4){fith <- list(try(sqrt("w"), silent=TRUE))} else {fith <- fitdd(data=Phigher, nls.control(maxiter=1000))}
+	if (lower & length(Plo) < 4){fitl <- list(try(sqrt("w"), silent=TRUE))} else {fitl <- fitdd(data=Plower, nls.control(maxiter=1000))}
+	if (higher & length(Phi) < 4){fith <- list(try(sqrt("w"), silent=TRUE))} else {fith <- fitdd(data=Phigher, nls.control(maxiter=1000))}
 #was:    fith <- fitdd(data=Phigher, nls.control(maxiter=1000))
 
 	# set NAs right for plotting:
@@ -62,15 +70,16 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
     if (plot.it){
       plotfit <- function(data, fit, ...){
           plot(data$P ~ data$k, log="xy", pch=16, xlab="number of links [k]", ylab="cumulative distribution", ...)
-          for (i in 1:length(fit)){
-              lines(seq(1, max(ddlower), by=0.1), predict(fit[[i]],
+          abline(h=1, lty=2)
+          for (i in 1:3){
+              if (!inherits(fit[[i]], "try-error")) lines(seq(1, max(ddlower), by=0.1), predict(fit[[i]],
                 newdata=data.frame(k=seq(1, max(ddlower), by=0.1))), col=paste("grey", i*20, sep=""), ...)
           }
-          abline(h=1, lty=2)
+          
       }
-      if (pure.call) par(mfrow=c(1,2), mar=c(5,5,4,1))
-      plotfit(data=Plower, fit=fitnew, lwd=2, cex=1.8, cex.lab=1.5, main="lower trophic level")
-      plotfit(data=Phigher, fit=fithnew, lwd=2, cex=1.8, cex.lab=1.5, main="higher trophic level")
+      if (pure.call & level == "both") par(mfrow=c(1,2), mar=c(5,5,4,1)) else par(mar=c(5,5,4,1))
+      if (lower) plotfit(data=Plower, fit=fitl, lwd=2, cex=1.8, cex.lab=1.5, main="lower trophic level", ...)
+      if (higher) plotfit(data=Phigher, fit=fith, lwd=2, cex=1.8, cex.lab=1.5, main="higher trophic level", ...)
     }
 
     res.out <- matrix(ncol=5, nrow=3)
@@ -78,8 +87,8 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
     colnames(res.out) <- c("Estimate", "Std. Error", "Pr(>|t|)", "R2", "AIC")
 
 	# if all fits are "try-error":
-	if (all(sapply(fitl, function(x) inherits(x, "try-error")))) only.na.low <- TRUE else only.na.low <- FALSE
-	if (all(sapply(fith, function(x) inherits(x, "try-error")))) only.na.high <- TRUE else only.na.high <- FALSE
+	if (lower & all(sapply(fitl, function(x) inherits(x, "try-error")))) only.na.low <- TRUE else only.na.low <- FALSE
+	if (higher & all(sapply(fith, function(x) inherits(x, "try-error")))) only.na.high <- TRUE else only.na.high <- FALSE
 	
 	# lower trophic level:
     resl.out <- res.out
@@ -99,9 +108,11 @@ function(web, plot.it=TRUE, pure.call=TRUE, silent=TRUE){
 		resh.out[indexh, 1:3] <- resh1
 	}
 
-    list("lower level dd fits"=resl.out, "higher level dd fits"=resh.out)
+    if (level == "both"){
+    	 out <- list("lower level dd fits"=resl.out, "higher level dd fits"=resh.out)
+ 	} else {
+ 		out <- if(lower) list("lower level dd fits"=resl.out) else "higher level dd fits"=resh.out
+ 	}
+ 	return(out)
 
 }
-
-#data(Safariland)
-#degreedistr(web=Safariland)
\ No newline at end of file
